Update function signatures for focused element change notifications

- Replace 'Node' in function names with 'Element'
- Replace Node/WebNode arguments with Element/WebElement
- Update arguments' variable names.

This CL has no behavior changes.

Change-Id: I5fb783ad9cf3cbe7944de933d5331f57822c8eea
Reviewed-on: https://chromium-review.googlesource.com/c/chromium/src/+/1609749
Reviewed-by: Kinuko Yasuda <[email protected]>
Reviewed-by: Bo <[email protected]>
Reviewed-by: Rouslan Solomakhin <[email protected]>
Reviewed-by: sebsg <[email protected]>
Commit-Queue: Kent Tamura <[email protected]>
Cr-Commit-Position: refs/heads/master@{#662003}
diff --git a/content/renderer/render_frame_impl.h b/content/renderer/render_frame_impl.h
index a2e8b0e7..53615e6 100644
--- a/content/renderer/render_frame_impl.h
+++ b/content/renderer/render_frame_impl.h
@@ -356,14 +356,14 @@
   void HandleWebAccessibilityEvent(const blink::WebAXObject& obj,
                                    ax::mojom::Event event);
 
-  // The focused node changed to |node|. If focus was lost from this frame,
-  // |node| will be null.
-  void FocusedNodeChanged(const blink::WebNode& node);
+  // The focused element changed to |element|. If focus was lost from this
+  // frame, |element| will be null.
+  void FocusedElementChanged(const blink::WebElement& element);
 
   // TODO(dmazzoni): the only reason this is here is to plumb it through to
   // RenderAccessibilityImpl. It should use the RenderFrameObserver method, once
   // blink has a separate accessibility tree per frame.
-  void FocusedNodeChangedForAccessibility(const blink::WebNode& node);
+  void FocusedElementChangedForAccessibility(const blink::WebElement& element);
 
   // A RenderView opened by this RenderFrame needs to be shown.
   void ShowCreatedWindow(bool opened_by_user_gesture,